@@ -8,9 +8,9 @@ class basic_income(Variable):
     unit = USD
     documentation = "Total basic income payments for this person. Phase-outs as an equal percentage to all tax unit members."
     definition_period = YEAR
-    defined_for = "basic_income_eligible"
 
     def formula(person, period, parameters):
+        eligible = person.tax_unit("basic_income_eligible", period)
         basic_income = person("basic_income_before_phase_out", period)
         tax_unit = person.tax_unit
         tax_unit_basic_income = tax_unit.sum(basic_income)
@@ -20,4 +20,4 @@ class basic_income(Variable):
             tax_unit_phase_out / tax_unit_basic_income,
             0,
         )
-        return basic_income * (1 - percent_reduction)
+        return basic_income * eligible * (1 - percent_reduction)
