@@ -16,6 +16,8 @@ class salt_deduction(Variable):
             period,
             ["state_and_local_sales_or_income_tax", "real_estate_taxes"],
         )
-        salt = parameters(period).irs.deductions.itemized.salt_and_real_estate
+        salt = parameters(
+            period
+        ).gov.irs.deductions.itemized.salt_and_real_estate
         cap = salt.cap[tax_unit("filing_status", period)]
         return min_(cap, salt_amount)
