@@ -8,4 +8,6 @@ class taxable_income_deductions_if_not_itemizing(Variable):
     unit = USD
     definition_period = YEAR
 
-    formula = sum_of_variables("irs.deductions.deductions_if_not_itemizing")
+    formula = sum_of_variables(
+        "gov.irs.deductions.deductions_if_not_itemizing"
+    )
